@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-Net::Google
+Net::Google - simple OOP-ish interface to the Google SOAP API
 
 =head1 SYNOPSIS
 
@@ -12,6 +12,8 @@ Net::Google
  my $google = Net::Google->new(key=>LOCAL_GOOGLE_KEY);
  my $search = $google->search();
 
+ # Search interface
+
  $search->query(qw(aaron straup cope));
  $search->lr(qw(en fr));
  $search->ie("utf8");
@@ -21,6 +23,25 @@ Net::Google
 
  map { print $_->title()."\n"; } @{$search->results()};
 
+ # or...
+
+ foreach my $r (@{$search->response()}) {
+   print "Search time :".$r->searchTime()."\n";
+
+   # returns an array ref of Result objects
+   # the same as the $search->results() method
+   map { print $_->URL()."\n"; } @{$r->resultElements()};
+ }
+
+ # Spelling interface
+
+ print $google->spelling(phrase=>"muntreal qwebec")->suggest(),"\n";
+
+ # Cache interface
+
+ my $cache = $google->cache(url=>"http://search.cpan.org/recent");
+ print $cache->get();
+
 =head1 DESCRIPTION
 
 Provides a simple OOP-ish interface to the Google SOAP API
@@ -39,7 +60,7 @@ use Net::Google::Search;
 use Net::Google::Spelling;
 use Net::Google::Cache;
 
-$Net::Google::VERSION   = 0.4;
+$Net::Google::VERSION   = '0.5';
 @Net::Google::ISA       = qw ( Exporter );
 @Net::Google::EXPORT    = qw ();
 @Net::Google::EXPORT_OK = qw ();
@@ -70,11 +91,15 @@ Valid arguments are :
 
 =over
 
-=item B<key>
+=item *
+
+B<key>
 
 I<String>. 
 
-=item B<debug>
+=item *
+
+B<debug>
 
 I<Boolean>
 
@@ -110,35 +135,51 @@ Valid arguments are :
 
 =over
 
-=item B<key>
+=item *
+
+B<key>
 
 String. Google API key. If none is provided then the key passed to the parent I<Net::Google> object will be used.
 
-=item B<starts_at>
+=item *
+
+B<starts_at>
 
 Int. First result number to display. Default is 0.
 
-=item B<max_results>
+=item *
+
+B<max_results>
 
 Int. Number of results to return. Default is 10.
 
-=item B<lr>
+=item *
+
+B<lr>
 
 String or array reference. Language restrictions.
 
-=item B<ie>
+=item *
+
+B<ie>
 
 String or array reference. Input encoding.
 
-=item B<oe>
+=item *
+
+B<oe>
 
 String or array reference. Output encoding.
 
-=item B<safe>
+=item *
+
+B<safe>
 
 Boolean.
 
-=item B<filter>
+=item *
+
+B<filter>
 
 Boolean.
 
@@ -168,15 +209,21 @@ sub search {
 
 =over
 
-=item B<key>
+=item *
+
+B<key>
 
 String. Google API key. If none is provided then the key passed to the parent I<Net::Google> object will be used.
 
-=item B<phrase>
+=item *
+
+B<phrase>
 
 String or array reference.
 
-=item B<debug>
+=item *
+
+B<debug>
 
 Int.If none is provided then the debug argument passed to the parent I<Net::Google> object will be used.
 
@@ -208,15 +255,21 @@ Valid arguments are :
 
 =over
 
-=item B<key>
+=item *
+
+B<key>
 
 String. Google API key. If none is provided then the key passed to the parent I<Net::Google> object will be used.
 
-=item B<url>
+=item *
+
+B<url>
 
 String.
 
-=item B<debug>
+=item *
+
+B<debug>
 
 Int.If none is provided then the debug argument passed to the parent I<Net::Google> object will be used.
 
@@ -296,16 +349,20 @@ sub _service {
 
 =head1 VERSION
 
-0.4
+0.5
 
 =head1 DATE
 
-April 14, 2002
+May 03, 2002
 
 =head1 AUTHOR
 
 Aaron Straup Cope
 
+=head1 CONTRIBUTORS
+
+Marc Hedlund <marc@precipice.org>
+
 =head1 SEE ALSO
 
 http://www.google.com/apis
@@ -316,11 +373,13 @@ L<Net::Google::Spelling>
 
 L<Net::Google::Cache>
 
+L<Net::Google::Response>
+
 =head1 TO DO
 
 =over
 
-=item
+=item *
 
 Add some sort of functionality for managing multiple keys. Sort of like what is describe here :
 
