@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-Net::Google::Cache
+Net::Google::Cache - simple OOP-ish interface to the Google SOAP API for cached documents
 
 =head1 SYNOPSIS
 
@@ -26,7 +26,7 @@ use strict;
 use Carp;
 use Exporter;
 
-$Net::Google::Cache::VERSION   = 0.1;
+$Net::Google::Cache::VERSION   = '0.1.2';
 @Net::Google::Cache::ISA       = qw (Exporter);
 @Net::Google::Cache::EXPORT    = qw ();
 @Net::Google::Cache::EXPORT_OK = qw ();
@@ -41,11 +41,15 @@ Valid arguments are :
 
 =over
 
-=item B<key>
+=item *
+
+B<key>
 
 String. Google API key. If none is provided then the key passed to the parent I<Net::Google> object will be used.
 
-=item B<url>
+=item *
+
+B<url>
 
 String.
 
@@ -146,11 +150,11 @@ sub get {
 
 =head1 VERSION
 
-0.1
+0.1.2
 
 =head1 DATE
 
-April 14, 2002
+May 01, 2002
 
 =head1 AUTHOR
 
@@ -160,7 +164,7 @@ Aaron Straup Cope
 
 =over
 
-=item 
+=item *
 
 Add hooks to I<get> method to strip out Google headers and footers from cached pages.
 
