@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-Net::Google::Spelling
+Net::Google::Spelling - simple OOP-ish interface to the Google SOAP API for spelling suggestions
 
 =head1 SYNOPSIS
 
@@ -26,7 +26,7 @@ use strict;
 use Carp;
 use Exporter;
 
-$Net::Google::Spelling::VERSION   = 0.1;
+$Net::Google::Spelling::VERSION   = '0.1.2';
 @Net::Google::Spelling::ISA       = qw (Exporter);
 @Net::Google::Spelling::EXPORT    = qw ();
 @Net::Google::Spelling::EXPORT_OK = qw ();
@@ -41,11 +41,15 @@ Valid arguments are :
 
 =over
 
-=item B<key>
+=item *
+
+B<key>
 
 String. Google API key. If none is provided then the key passed to the parent I<Net::Google> object will be used.
 
-=item B<phrase>
+=item *
+
+B<phrase>
 
 String or array reference.
 
@@ -152,11 +156,11 @@ sub suggest {
 
 =head1 VERSION
 
-0.1
+0.1.2
 
 =head1 DATE
 
-April 14, 2002
+May 01, 2002
 
 =head1 AUTHOR
 
